@@ -7,7 +7,9 @@ class DiffTestCase(GitTestCase):
     def test_get_diff_from_status(self):
         with tempgitdir() as tmpdir:
             test_file = tmpdir / "foo.txt"
-            test_file.write_text("Lorem\nipsum\ndolor\nsit\namet", encoding="utf8")
+            test_file.write_text(
+                "Lorem\nipsum\ndolor\nsit\namet", encoding="utf8"
+            )
 
             git_add(test_file)
             git_commit()
@@ -28,7 +30,9 @@ class DiffTestCase(GitTestCase):
     def test_get_diff(self):
         with tempgitdir() as tmpdir:
             test_file = tmpdir / "foo.txt"
-            test_file.write_text("Lorem\nipsum\ndolor\nsit\namet", encoding="utf8")
+            test_file.write_text(
+                "Lorem\nipsum\ndolor\nsit\namet", encoding="utf8"
+            )
 
             git_add(test_file)
             git_commit()
